package cn.wise.sc.consume.business.entity.cmbnoenet;

import cn.wise.sc.consume.business.entity.SysMember;
import cn.wise.sc.consume.business.entity.cmbnoenet.model.BaseResponse;
import cn.wise.sc.consume.business.entity.cmbnoenet.model.TokenInfoQuery;
import cn.wise.sc.consume.business.model.SysEnterpriseDto;
import cn.wise.sc.consume.business.service.impl.CMBOneNetPayService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * @description: 招行一卡通
 * @author: qh
 * @create: 2020-04-09 17:05
 */
@Api(tags = "企业app接口")
@CrossOrigin
@RestController
@RequestMapping("/cmbOneNet")
public class CMBOneNetController {
	private static final Logger log = LoggerFactory.getLogger("CMBOneNetController");
    final  CMBOneNetPayService CMBOneNetPayService;

    public CMBOneNetController(CMBOneNetPayService CMBOneNetPayService) {
        this.CMBOneNetPayService = CMBOneNetPayService;
    }

    @ApiOperation("获取招行app支付订单信息")
    @PostMapping("/fmordsubOrderInfo")
    public BaseResponse fmordsubOrderInfo(
            String orderNo, String txnAmt, String receAccount, String receName, String receBank)
            throws Exception {
        return CMBOneNetPayService.oneNetOrderInfo(orderNo, txnAmt, receAccount, receName, receBank);
    }

    @ApiOperation("订单支付回调")
    @PostMapping("/payNotice")
    public BaseResponse payNotice(HttpServletRequest request) {
        return BaseResponse.okMsg("招行一卡通支付回调!", CMBOneNetPayService.getClass());
    }

    //****************************************************************


	@ApiOperation("申请Api访问令牌")
	@PostMapping("/applyInfo")
	public BaseResponse getApplyInfo(@RequestBody String authCode){
		return CMBOneNetPayService.getApplyInfo(authCode);
	}

	@ApiOperation("续费Api访问令牌")
	@PutMapping("/reNewApplyInfo")
	public BaseResponse reNewApplyInfo(@RequestBody String token){
		return CMBOneNetPayService.renewApplyInfo(token);
	}

	@ApiOperation("查询企业信息")
	@GetMapping("/getEnterprise")
	public BaseResponse getEnterprise(String coridc,  String token){
		return CMBOneNetPayService.getEnterprise(coridc, token);
	}

	@ApiOperation("查询企业用户信息")
	@GetMapping("/getEnterpriseUser")
	public BaseResponse getEnterpriseUser(String usridc,  String token){
		return CMBOneNetPayService.getEnterpriseUser(usridc, token);
	}

	@ApiOperation("查询企业用户证件信息")
	@GetMapping("/getEnterpriseUserCard")
	public BaseResponse getEnterpriseUserCard(String usridc,  String token){
		return CMBOneNetPayService.getEnterpriseUserCard(usridc, token);
	}

	@ApiOperation("查询企业核心客户号")
	@GetMapping("/getEnterpriseClientId")
	public BaseResponse getEnterpriseClientId(String coridc,  String token){
		return CMBOneNetPayService.getEnterpriseClientId(coridc, token);
	}

	@ApiOperation("查询自然人用户信息")
	@GetMapping("/getNatural")
	public BaseResponse getNatural(String glbuid,  String token){
		return CMBOneNetPayService.getNatural(glbuid, token);
	}


	@ApiOperation("解析握手令牌token,获取招行App用户信息")
	@PostMapping("/getUserInforMation")
	public BaseResponse getUserInforMation(@RequestBody TokenInfoQuery tokenInfoQuery) {
		return CMBOneNetPayService.getUserInforMation(tokenInfoQuery.getSignature(), tokenInfoQuery.getData());
	}


	@ApiOperation("判断企业申请状态")
	@PostMapping("/getUserInfo")
	public BaseResponse getUserInfo(@RequestBody String coridc) {
		return CMBOneNetPayService.getUserInfo(coridc);
	}

	@ApiOperation(value = "申请发券")
	@PostMapping("/applyEnterprise")
	public BaseResponse applyEnterprise(@RequestBody SysEnterpriseDto enterpriseDto) {
		return CMBOneNetPayService.applyEnterprise(enterpriseDto);
	}

	@ApiOperation(value = "票券列表（企业列表）")
	@GetMapping("/getEnterpriseList")
	public BaseResponse getEnterpriseList(String usridc) {
		return CMBOneNetPayService.getEnterpriseList(usridc);
	}

	@ApiOperation(value = "会员申请")
	@PostMapping("/applyMember")
	public BaseResponse applyMember(@RequestBody SysMember sysMember) {
		return CMBOneNetPayService.applyMember(sysMember);
	}

	@ApiOperation(value = "领券列表")
	@GetMapping("/getCouponAppList")
	public BaseResponse getCouponAppList(String coridc, String usridc) {
		return CMBOneNetPayService.getCouponAppList(coridc, usridc);
	}

	@ApiOperation(value = "领取")
	@GetMapping("/receive")
	public BaseResponse receive(String couponId, String usridc) {
		return CMBOneNetPayService.receive(couponId, usridc);
	}

	@ApiOperation(value = "已领取优惠券列表")
	@GetMapping("/getReceivedList")
	public BaseResponse getReceivedList(String coridc, String usridc) {
		return CMBOneNetPayService.getReceivedList(coridc, usridc);
	}

	@ApiOperation(value = "使用优惠券")
	@GetMapping("/useCoupon")
	public BaseResponse useCoupon(Long couponDetailId) {
		return CMBOneNetPayService.useCoupon(couponDetailId);
	}











}
