package cn.wise.sc.consume.business.service.impl;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.lang.Snowflake;
import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import cn.wise.sc.consume.business.entity.SysCouponDetail;
import cn.wise.sc.consume.business.entity.SysEnterprise;
import cn.wise.sc.consume.business.entity.SysMember;
import cn.wise.sc.consume.business.entity.SysUserCoupon;
import cn.wise.sc.consume.business.entity.cmbnoenet.AllInOneNetUtil;
import cn.wise.sc.consume.business.entity.cmbnoenet.model.*;
import cn.wise.sc.consume.business.mapper.SysEnterpriseMapper;
import cn.wise.sc.consume.business.model.CouponAppListVO;
import cn.wise.sc.consume.business.model.EnterpriseAppListVO;
import cn.wise.sc.consume.business.model.ReceivedAppListVO;
import cn.wise.sc.consume.business.model.SysEnterpriseDto;
import cn.wise.sc.consume.business.service.*;
import com.alibaba.fastjson.JSON;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.PropertySource;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpMethod;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.web.client.RestTemplate;

import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 招行一卡通 支付
 */
@Slf4j
@Service
@PropertySource("classpath:wechat.properties")
@ConfigurationProperties(prefix = "wechat.mp")
public class CMBOneNetPayService {

	private static final Logger log = LoggerFactory.getLogger("CMBOneNetPayService");

    @Value("${wechat.oneNet.merId}")
    private String merId;
	@Value("${wechat.oneNet.tppidc}")
	private String tppidc;
	@Autowired
	private ISysEnterpriseService enterpriseService;
	@Autowired
	private ISysMemberService memberService;
	@Autowired
	private ISysCouponService couponService;
	@Autowired
	private ISysCouponDetailService couponDetailService;
	@Autowired
	private ISysUserCouponService userCouponService;

    /**
     * 解析app端授权信息
     *
     * @param signature Token 报文签名信息，使用开放平台私钥对加密后的数据的哈希值进 行签名。采用 2048 位 RSA 密钥签名时，其长度固定为 344 字节
     * @param data      采用分行小程序公钥进行 RSA 加密后的 Token 报文
     * @return
     */
    public BaseResponse getUserInforMation(String signature, String data) {
        if (StrUtil.isEmpty(data) || StrUtil.isEmpty(signature)) {
            return BaseResponse.error("signature和data为必填项!", this.getClass().getName());
        }
        // signature和 data转码    signature和目前用不上
        signature = transcoding(signature);
        data = transcoding(data);
	    System.out.println("==================data===================");
	    System.out.println(data);

	    try {
		    String token = AllInOneNetUtil.decrypt(AllInOneNetUtil.priKey, data);
		    CMBOneNetTokenInfo cmbOneNetTokenInfo = JSON.parseObject(token, CMBOneNetTokenInfo.class);
		    return BaseResponse.ok(cmbOneNetTokenInfo);
	    } catch (Exception e) {
		    log.error("招行一卡通手令牌解析异常! 参数:{}", data);
		    return BaseResponse.error(e.getMessage(), this.getClass().getName());
	    }
    }


	/**
	 * 判断企业申请状态
	 *
	 * @param coridc 企业id
	 * @return
	 */
	public BaseResponse getUserInfo(String coridc) {
		if (StrUtil.isEmpty(coridc) ) {
			return BaseResponse.error("coridc为必填项!", this.getClass().getName());
		}
		try {
			QueryWrapper<SysEnterprise> wrapper = new QueryWrapper<>();
			if (StringUtils.isNotBlank(coridc)) {
				wrapper.eq("coridc", coridc);
			}
			SysEnterprise e = enterpriseService.getOne(wrapper);
			if (e == null || e.getId() == null) {
				return BaseResponse.ok("register Enterprise");
			}else{
				return BaseResponse.ok(e);
			}
		} catch (Exception e) {
			log.error("判断企业申请状态异常! 参数:{}", coridc);
			return BaseResponse.error(e.getMessage(), this.getClass().getName());
		}
	}

	/**
	 * 企业入驻申请
	 *
	 * @param enterpriseDto 申请企业类
	 * @return
	 */
	public BaseResponse applyEnterprise(SysEnterpriseDto enterpriseDto) {
		try {
			QueryWrapper<SysEnterprise> wrapper = new QueryWrapper<>();
			if (StringUtils.isNotBlank(enterpriseDto.getCoridc())) {
				wrapper.eq("coridc", enterpriseDto.getCoridc());
			}
			SysEnterprise e = enterpriseService.getOne(wrapper);
			if (e != null) {
				return BaseResponse.error("企业信息已存在!", this.getClass().getName());
			}
			//保存企业表信息
			SysEnterprise enterprise = enterpriseDto;
			enterprise.setStatus(2);//app端申请的企业为待审批状态，需要管理员在管理端审批后才能正常使用
			enterprise.setIsDelete(1);
			enterprise.setCreateTime(LocalDateTime.now());
			enterpriseService.save(enterprise);
			return BaseResponse.ok("成功");
		} catch (Exception e) {
			log.error("企业入驻申请异常! 参数:{}", enterpriseDto.getEnterpriseName());
			return BaseResponse.error(e.getMessage(), this.getClass().getName());
		}
	}


	/**
	 * 企业列表 (展示审批通过的企业信息，和当前app的用户id是否已经绑定会员信息)
	 * @return
	 */
	public BaseResponse getEnterpriseList(String usridc) {
		try {
			List<EnterpriseAppListVO>  enterpriseAppListVOS = enterpriseService.getEnterpriseList(usridc);
			return BaseResponse.ok(enterpriseAppListVOS);
		} catch (Exception e) {
			log.error("企业列表异常! 参数:{}", usridc);
			return BaseResponse.error(e.getMessage(), this.getClass().getName());
		}
	}


	/**
	 * 会员申请
	 * @return
	 */
	public BaseResponse applyMember(SysMember sysMember) {
		try {
			sysMember.setCreateTime(LocalDateTime.now());
			memberService.save(sysMember);
			return BaseResponse.ok("成功");
		} catch (Exception e) {
			log.error("会员申请异常! 参数:{}", sysMember);
			return BaseResponse.error(e.getMessage(), this.getClass().getName());
		}
	}



	/**
	 * 企业优惠券列表  领券列表
	 * @return
	 */
	public BaseResponse getCouponAppList(String coridc, String usridc) {
		try {
			couponDetailService.beVerdue();
			List<CouponAppListVO> list = couponService.getCouponAppList(coridc, usridc);
			return BaseResponse.ok(list);
		} catch (Exception e) {
			log.error("企业优惠券列表异常! 参数:{}", coridc+","+usridc);
			return BaseResponse.error(e.getMessage(), this.getClass().getName());
		}
	}



	/**领取优惠券
	 *
	 * @param couponId 优惠券表id
	 * @param usridc 企业用户id
	 * @return
	 */
	public BaseResponse receive(String couponId, String usridc) {
		try {
			QueryWrapper<SysCouponDetail> couponDetailWrapper = new QueryWrapper<>();
			couponDetailWrapper.eq("coupon_id", couponId);
			couponDetailWrapper.eq("is_delete",1);
			couponDetailWrapper.eq("is_receive",0);
			List<SysCouponDetail> list = couponDetailService.list(couponDetailWrapper);
			if(list == null || list.size()<=0){
				return BaseResponse.error("无可用优惠券!", this.getClass().getName());
			}
			SysCouponDetail couponDetail = list.get(0);
			SysUserCoupon userCoupon = new SysUserCoupon();
			userCoupon.setUserId(usridc);
			userCoupon.setCouponDetailId(couponDetail.getId());
			userCoupon.setIsUse(0);
			userCoupon.setCreateTime(LocalDateTime.now());
			userCouponService.save(userCoupon);
			couponDetail.setIsReceive(1);
			couponDetailService.save(couponDetail);

			return BaseResponse.ok("成功");
		} catch (Exception e) {
			log.error("领取优惠券异常! 参数:{}", couponId+","+usridc);
			return BaseResponse.error(e.getMessage(), this.getClass().getName());
		}
	}


	/**已领取优惠券列表
	 *
	 * @param coridc 企业编号
	 * @param usridc 企业用户id
	 * @return
	 */
	public BaseResponse getReceivedList(String coridc, String usridc) {
		try {
			List<ReceivedAppListVO>  list = couponDetailService.getReceivedList(coridc, usridc);
			return BaseResponse.ok(list);
		} catch (Exception e) {
			log.error("领取优惠券异常异常! 参数:{}", coridc+","+usridc);
			return BaseResponse.error(e.getMessage(), this.getClass().getName());
		}
	}


	//复制券码即可在链接中使用  不用接口

	//根据第三方接口查询券码是否使用，如果使用改变用户优惠券表的使用状态。

	public BaseResponse useCoupon(Long couponDetailId) {
		try {
			QueryWrapper<SysUserCoupon> userCouponWrapper = new QueryWrapper<>();
			userCouponWrapper.eq("coupon_detail_id", couponDetailId);
			SysUserCoupon userCoupon = userCouponService.getOne(userCouponWrapper);
			if(userCoupon == null){
				return BaseResponse.error("优惠券信息错误!", this.getClass().getName());
			}
			if(userCoupon.getIsUse() != 0 ){
				return BaseResponse.error("优惠券已使用或一过期!", this.getClass().getName());
			}
			userCoupon.setIsUse(1);
			userCoupon.setUseTime(LocalDateTime.now());
			userCouponService.updateById(userCoupon);
			return BaseResponse.ok("成功");
		} catch (Exception e) {
			log.error("领取优惠券异常异常! 参数:{}", couponDetailId);
			return BaseResponse.error(e.getMessage(), this.getClass().getName());
		}
	}







	/**
	 * 将参数中的 +换成- ,/替换成_
	 *
	 * @param waitTransStr 带处理字符串
	 * @return String
	 */
    private String transcoding(String waitTransStr) {
        return waitTransStr.replace("\\+", "-").replace("\\/", "_");
    }

    /**
     * 招行一卡通 推送订单信息
     *
     * @param orderNo     订单号
     * @param txnAmt      金额
     * @param receAccount 接收方账户
     * @param receName    接收方账户名
     * @param receBank    接收方开户银行
     * @return
     */
    public BaseResponse oneNetOrderInfo(
            String orderNo, String txnAmt, String receAccount, String receName, String receBank)
            throws Exception {

        // 封装业务参数
        CMBOneNetOrderParams params = new CMBOneNetOrderParams();
        params.setCcynbr("10");
        params.setMchtyp("MCHTYP004");
        params.setRcvbbk("313234001089");
        params.setRcveac(receAccount);
        params.setReford(orderNo);
        params.setTrsamt(txnAmt);
        params.setRcvean(receName);
        Map<String, String> bodyMap = new HashMap<>();
        bodyMap.put("orderinfo", JSON.toJSONString(params));



        // 请求订单信息
        CMBONeNetResponse cmboNeNetResponse =
                postCMBApi("", CMBOneNetRequestUrl.ORDERINFO_URL, "");

        // 处理响应结果
        if (cmboNeNetResponse != null) {
            if ("SUC0000".equals(cmboNeNetResponse.getResponse().getHead().getRetcod())) {
                Map<String, String> result = new HashMap(3);
                // 解密实例流程号
                CMBOneNetResponseFlow cmbOneNetResponseFlow =
                        decodeFlowNo(cmboNeNetResponse.getResponse().getBody());
                String flow = cmbOneNetResponseFlow.getSubresult().getSeqnbr();
                String merId = cmboNeNetResponse.getResponse().getHead().getTppidc();
                String time = cmboNeNetResponse.getResponse().getHead().getRsptim();
                String sigdat = sigdat(flow, time, time);
                String srcdat = srcdat(flow, merId, time);
                result.put("sigdat", sigdat);
                result.put("srcdat", srcdat);
                result.put("merId", merId);
                return BaseResponse.ok(result);
            }
            return BaseResponse.error(cmboNeNetResponse.getResponse().getHead().getRetmsg(), "招行一卡通支付");
        } else {
            return BaseResponse.error("唤起招行一卡通失败", "招行一卡通支付");
        }
    }

    /**
     * 获取Api访问令牌
     *
     * @param authCode 授权码
     * @return acctkn
     */
    public BaseResponse getApplyInfo(String authCode) {
        if (StrUtil.isEmpty(authCode)) {
            return BaseResponse.error("授权码是必填项", this.getClass().getName());
        }
		String body = "{\"applyinfo\":{\"autcod\":\"" + authCode + "\"}}";
        CMBONeNetResponse cmboNeNetResponse = null;
        try {
            cmboNeNetResponse = postCMBApi(body, CMBOneNetRequestUrl.APPLYINFO_URL, "FOATKAPL");
        } catch (Exception e) {
            log.error("发起获取Api访问令牌的请求失败! 参数:{}", body);
        }
		String rest = JSON.toJSONString(cmboNeNetResponse);
	    System.out.println(rest);

        // 处理响应
        if (cmboNeNetResponse != null) {
            if ("SUC0000".equals(cmboNeNetResponse.getResponse().getHead().getRetcod())) {
                String response = null;
                try {
                    response =
                            AllInOneNetUtil.decrypt(
                                    AllInOneNetUtil.priKey, cmboNeNetResponse.getResponse().getBody());
                } catch (Exception e) {
                    log.error("解析获取访问令牌响应失败!参数:{}", response);
                    return BaseResponse.error("获取访问令牌失败!", this.getClass().getName());
                }
                return BaseResponse.ok(response);
            }
            return BaseResponse.error(cmboNeNetResponse.getResponse().getHead().getRetmsg(), this.getClass().getName());
        } else {
            return BaseResponse.error("获取访问令牌失败!", this.getClass().getName());
        }
    }

	/**
     * 续费访问token
     * 1.过期2h不得续费
     * 2.续费次数超过4次 不得续费
     *
     * @param token 带续费的token
     * @return BaseResponse
     */
    public BaseResponse renewApplyInfo(String token) {

        if (StrUtil.isEmpty(token)) {
            return BaseResponse.error("token参数是必填的!", this.getClass().getName());
        }
	    String body = "{\"renewinfo\":{\"acctkn\":\"" + token + "\"}}";
        CMBONeNetResponse cmboNeNetResponse = null;
        try {
            cmboNeNetResponse = postCMBApi(body, CMBOneNetRequestUrl.RENEWINFO_URL, "FOATKNEW");
        } catch (Exception e) {
            log.error("续费Api访问令牌的请求失败! 参数:{}", body);
        }
        // 处理响应
        if (cmboNeNetResponse != null) {
            if ("SUC0000".equals(cmboNeNetResponse.getResponse().getHead().getRetcod())) {
                String response = null;
                try {
                    response =
                            AllInOneNetUtil.decrypt(
                                    AllInOneNetUtil.priKey, cmboNeNetResponse.getResponse().getBody());
                } catch (Exception e) {
                    log.error("续费Api访问令牌的请求失败!参数:{}", response);
                    return BaseResponse.error("续费Api访问令牌的请求失败!", this.getClass().getName());
                }
                return BaseResponse.ok(response);
            }
            return BaseResponse.error(cmboNeNetResponse.getResponse().getHead().getRetmsg(), this.getClass().getName());
        } else {
            return BaseResponse.error("续费Api访问令牌的请求失败!", this.getClass().getName());
        }
    }


	/**
	 * 查询企业信息
	 *
	 * @param coridc 企业 ID
	 * @param acctkn 访问令牌值
	 * @return acctkn
	 */
	public BaseResponse getEnterprise(String coridc, String acctkn) {
		if (StrUtil.isEmpty(coridc) || StrUtil.isEmpty(acctkn)) {
			return BaseResponse.error("企业ID访问令牌值是必填项", this.getClass().getName());
		}
		String body = "{\"corqryitf\":{\"coridc\":\"" + coridc + "\",\"acctkn\":\"" + acctkn + "\"}}";
		CMBONeNetResponse cmboNeNetResponse = null;
		try {
			cmboNeNetResponse = postCMBApi(body, CMBOneNetRequestUrl.CORQRYITF_URL, "FOCORQRY");
		} catch (Exception e) {
			log.error("查询企业信息请求失败! 参数:{}", JSON.toJSONString(body));
		}
		String rest = JSON.toJSONString(cmboNeNetResponse);
		System.out.println(rest);
		// 处理响应
		if (cmboNeNetResponse != null) {
			if ("SUC0000".equals(cmboNeNetResponse.getResponse().getHead().getRetcod())) {
				String response = null;
				try {
					response =
							AllInOneNetUtil.decrypt(
									AllInOneNetUtil.priKey, cmboNeNetResponse.getResponse().getBody());
				} catch (Exception e) {
					log.error("查询企业信息响应失败!参数:{}", response);
					return BaseResponse.error("查询企业信息失败!", this.getClass().getName());
				}
				return BaseResponse.ok(response);
			}
			return BaseResponse.error(cmboNeNetResponse.getResponse().getHead().getRetmsg(), this.getClass().getName());
		} else {
			return BaseResponse.error("查询企业信息失败!", this.getClass().getName());
		}
	}

	/**
	 * 查询企业用户信息
	 *
	 * @param usridc 用户 ID
	 * @param acctkn 访问令牌值
	 * @return acctkn
	 */
	public BaseResponse getEnterpriseUser(String usridc, String acctkn) {
		if (StrUtil.isEmpty(usridc) || StrUtil.isEmpty(acctkn)) {
			return BaseResponse.error("用户ID访问令牌值是必填项", this.getClass().getName());
		}
		String body = "{\"usrqryitf\":{\"usridc\":\"" + usridc + "\",\"acctkn\":\"" + acctkn + "\"}}";
		CMBONeNetResponse cmboNeNetResponse = null;
		try {
			cmboNeNetResponse = postCMBApi(body, CMBOneNetRequestUrl.USRQRYITF_URL, "FOUSRINF");
		} catch (Exception e) {
			log.error("查询企业用户信息请求失败! 参数:{}", JSON.toJSONString(body));
		}
		String rest = JSON.toJSONString(cmboNeNetResponse);
		System.out.println(rest);
		// 处理响应
		if (cmboNeNetResponse != null) {
			if ("SUC0000".equals(cmboNeNetResponse.getResponse().getHead().getRetcod())) {
				String response = null;
				try {
					response =
							AllInOneNetUtil.decrypt(
									AllInOneNetUtil.priKey, cmboNeNetResponse.getResponse().getBody());
				} catch (Exception e) {
					log.error("查询企业用户信息响应失败!参数:{}", response);
					return BaseResponse.error("查询企业用户信息失败!", this.getClass().getName());
				}
				return BaseResponse.ok(response);
			}
			return BaseResponse.error(cmboNeNetResponse.getResponse().getHead().getRetmsg(), this.getClass().getName());
		} else {
			return BaseResponse.error("查询企业用户信息失败!", this.getClass().getName());
		}
	}


	/**
	 * 查询企业用户证件信息
	 *
	 * @param usridc 用户 ID
	 * @param acctkn 访问令牌值
	 * @return acctkn
	 */
	public BaseResponse getEnterpriseUserCard(String usridc, String acctkn) {
		if (StrUtil.isEmpty(usridc) || StrUtil.isEmpty(acctkn)) {
			return BaseResponse.error("用户ID访问令牌值是必填项", this.getClass().getName());
		}
		String body = "{\"usrctfitf\":{\"usridc\":\"" + usridc + "\",\"acctkn\":\"" + acctkn + "\"}}";
		CMBONeNetResponse cmboNeNetResponse = null;
		try {
			cmboNeNetResponse = postCMBApi(body, CMBOneNetRequestUrl.USRCTFITF_URL, "FOUSRCTF");
		} catch (Exception e) {
			log.error("查询企业用户证件信息请求失败! 参数:{}", JSON.toJSONString(body));
		}
		String rest = JSON.toJSONString(cmboNeNetResponse);
		System.out.println(rest);
		// 处理响应
		if (cmboNeNetResponse != null) {
			if ("SUC0000".equals(cmboNeNetResponse.getResponse().getHead().getRetcod())) {
				String response = null;
				try {
					response =
							AllInOneNetUtil.decrypt(
									AllInOneNetUtil.priKey, cmboNeNetResponse.getResponse().getBody());
				} catch (Exception e) {
					log.error("查询企业用户证件信息响应失败!参数:{}", response);
					return BaseResponse.error("查询企业用户证件信息失败!", this.getClass().getName());
				}
				return BaseResponse.ok(response);
			}
			return BaseResponse.error(cmboNeNetResponse.getResponse().getHead().getRetmsg(), this.getClass().getName());
		} else {
			return BaseResponse.error("查询企业用户证件信息失败!", this.getClass().getName());
		}
	}

	/**
	 * 查询企业核心客户号
	 *
	 * @param coridc 企业 ID
	 * @param acctkn 访问令牌值
	 * @return acctkn
	 */
	public BaseResponse getEnterpriseClientId(String coridc, String acctkn) {
		if (StrUtil.isEmpty(coridc) || StrUtil.isEmpty(acctkn)) {
			return BaseResponse.error("企业ID访问令牌值是必填项", this.getClass().getName());
		}
		String body = "{\"cltqryitf\":{\"coridc\":\"" + coridc + "\",\"acctkn\":\"" + acctkn + "\"}}";
		CMBONeNetResponse cmboNeNetResponse = null;
		try {
			cmboNeNetResponse = postCMBApi(body, CMBOneNetRequestUrl.CLTQRYITF_URL, "FOCLTNRB");
		} catch (Exception e) {
			log.error("查询企业核心客户号信息请求失败! 参数:{}", JSON.toJSONString(body));
		}
		String rest = JSON.toJSONString(cmboNeNetResponse);
		System.out.println(rest);
		// 处理响应
		if (cmboNeNetResponse != null) {
			if ("SUC0000".equals(cmboNeNetResponse.getResponse().getHead().getRetcod())) {
				String response = null;
				try {
					response =
							AllInOneNetUtil.decrypt(
									AllInOneNetUtil.priKey, cmboNeNetResponse.getResponse().getBody());
				} catch (Exception e) {
					log.error("查询企业核心客户号信息响应失败!参数:{}", response);
					return BaseResponse.error("查询企业核心客户号信息失败!", this.getClass().getName());
				}
				return BaseResponse.ok(response);
			}
			return BaseResponse.error(cmboNeNetResponse.getResponse().getHead().getRetmsg(), this.getClass().getName());
		} else {
			return BaseResponse.error("查询企业核心客户号信息失败!", this.getClass().getName());
		}
	}



	/**
	 * 查询自然人用户信息
	 *
	 * @param glbuid 自然人编号
	 * @param acctkn 访问令牌值
	 * @return acctkn
	 */
	public BaseResponse getNatural(String glbuid, String acctkn) {
		if (StrUtil.isEmpty(glbuid) || StrUtil.isEmpty(acctkn)) {
			return BaseResponse.error("自然人编号访问令牌值是必填项", this.getClass().getName());
		}
		String body = "{\"glbqryitf\":{\"glbuid\":\"" + glbuid + "\",\"acctkn\":\"" + acctkn + "\"}}";
		CMBONeNetResponse cmboNeNetResponse = null;
		try {
			cmboNeNetResponse = postCMBApi(body, CMBOneNetRequestUrl.GLBQRYITF_URL, "FOGLBINF");
		} catch (Exception e) {
			log.error("查询自然人用户信息请求失败! 参数:{}", JSON.toJSONString(body));
		}
		String rest = JSON.toJSONString(cmboNeNetResponse);
		System.out.println(rest);
		// 处理响应
		if (cmboNeNetResponse != null) {
			if ("SUC0000".equals(cmboNeNetResponse.getResponse().getHead().getRetcod())) {
				String response = null;
				try {
					response =
							AllInOneNetUtil.decrypt(
									AllInOneNetUtil.priKey, cmboNeNetResponse.getResponse().getBody());
				} catch (Exception e) {
					log.error("查询自然人用户信息响应失败!参数:{}", response);
					return BaseResponse.error("查询自然人用户信息信息失败!", this.getClass().getName());
				}
				return BaseResponse.ok(response);
			}
			return BaseResponse.error(cmboNeNetResponse.getResponse().getHead().getRetmsg(), this.getClass().getName());
		} else {
			return BaseResponse.error("查询自然人用户信息失败!", this.getClass().getName());
		}
	}







    /**
     * 解密流程号
     *
     * @param flow 流程加密字段
     * @return
     */
    private CMBOneNetResponseFlow decodeFlowNo(String flow) {
        if (StrUtil.isEmpty(flow)) {
            throw new IllegalArgumentException("招行一卡通----流程号为空!");
        }
        try {
            String decryptFlow = AllInOneNetUtil.decrypt(AllInOneNetUtil.priKey, flow);
            return JSON.parseObject(decryptFlow, CMBOneNetResponseFlow.class);
        } catch (Exception e) {
            throw new RuntimeException("招行一卡通支付----解密实例流程号,异常！");
        }
    }

    /**
     * 获取唯一标识
     *
     * @return
     */
    private String getNewMsgidc() {
        Snowflake snowflake = IdUtil.createSnowflake(1, 1);
        return snowflake.nextIdStr();
    }

    /**
     * 逗号分隔，需要先加密、后签名。 流程实例号用于查订单
     *
     * @param seqnbr 流程实例号
     * @param merId  商户编号
     * @param time   时间 戳（格式为 yyyyMMddHHmmss
     * @return
     */
    private String sigdat(String seqnbr, String merId, String time) {
        return null;
    }

    /**
     * 逗号分隔，需要加密。流程实例号 用于查订单
     *
     * @param seqnbr 流程实例号
     * @param merId  商户编号
     * @param time   时间 戳（格式为 yyyyMMddHHmmss
     * @return
     */
    private String srcdat(String seqnbr, String merId, String time) {
        return null;
    }

    /**
     * 请求招行api
     *
     * @param body 请求体
     * @param url     api路径
     * @param trscod  类型 招行的trscod
     * @return ResponseEntity的body
     */
    private CMBONeNetResponse postCMBApi(String body, String url, String trscod)
            throws Exception {
        System.out.println("==================body===================");
        System.out.println(body);

        // 加密业务参数
        String bodyEncrypt = AllInOneNetUtil.encrypt(AllInOneNetUtil.pubKey, body, "utf-8");
        // 设置请求体中得head字段
        CMBOneNetRequestDataModel requestDataModel = new CMBOneNetRequestDataModel();
        requestDataModel.setBody(bodyEncrypt);

        CMBOneNetRequestDataModel.Header header = requestDataModel.new Header();
        // 商户号（分行应用id）
        header.setTppidc(tppidc);
        // 设置请求类型
        if (StrUtil.isNotEmpty(trscod)) {
            header.setTrscod(trscod);
        } else {
            header.setTrscod("FMORDSUB");
        }
        // 报文唯一标识
        header.setMsgidc(getNewMsgidc());
        String now = DateUtil.format(new Date(), "yyyyMMddHHmmss");
        header.setReqtim(now);

        requestDataModel.setHead(header);
        System.out.println("=====================数据域========================");
        System.out.println(JSON.toJSONString(requestDataModel));

        String sign = AllInOneNetUtil.sign(AllInOneNetUtil.priKey, JSON.toJSONString(requestDataModel), "utf-8");

        CMBOneNetRequestModel requestModel = new CMBOneNetRequestModel();
        requestModel.setRequest(requestDataModel);
        requestModel.setSignature(sign);

        HttpEntity<String> requestEntity =
                new HttpEntity<String>(JSON.toJSONString(requestModel), new HttpHeaders());
        RestTemplate template = new RestTemplate();

        ResponseEntity<String> response =
                template.exchange(url, HttpMethod.POST, requestEntity, String.class);
        if (response.getStatusCode().value() == 200) {
            String rst = response.getBody();
            return JSON.parseObject(rst, CMBONeNetResponse.class);
        }
        return null;
    }
}
